@@ -13,6 +13,8 @@ from .container import Container
 from .vault import Vault
 from .rest import Urls
 from .responses import (
+    AppRunResults,
+    AppRunResponse,
     CancelPlaybookResponse,
     CloseContainerResponse,
     CreateContainerAttachmentResponse,
@@ -444,13 +446,75 @@ class SplunkSoarClient:
         return False
 
     @_isConnected
-    def list_app_run(self, **kwargs) -> bool:
+    def list_app_run(
+            self,
+            page: int = None,
+            page_size: int = None, **kwargs) -> bool:
         """list app run"""
-        if self._get(Urls.app_run(**kwargs)):
-            self.app_run = self._content_dict()
-            return True
+        if self._get(Urls.app_run(page=page, page_size=page_size, **kwargs)):
+            self.app_run = AppRunResponse(self._content_dict())
+            response = AppRunResponse(self._content_dict())
+            response.data = [AppRunResults(x) for x in response.data]
+            log.info(f'list app runs, page: {page} page_size: {page_size}, {response.summary()}')
+            self.app_run = response
+            return response
         return False
 
+    @_isConnected
+    def list_app_run_generator(
+            self,
+            page: int = 0,
+            page_size: int = None,
+            max_pages: int = None, **kwargs) -> AppRunResults or bool:
+        """Generator for paging through app runs"""
+
+        page = page
+
+        while True:
+            response = self.list_app_run(page=page, page_size=page_size, **kwargs)
+            if response.data:
+                app_runs = response.data
+                num_pages = response.num_pages
+                log.info(f'{page}/{num_pages} ({round(page / num_pages * 100, 2)}%)')
+
+                if page >= num_pages or page >= max_pages:
+                    log.info(f'list app runs finished')
+                    return True
+
+                yield app_runs
+                page += 1
+
+            elif response.data == []:
+                log.info(f'{page}/{num_pages} ({round(page / num_pages * 100, 2)}%)')
+                log.info(f'list app runs finished. {response}')
+                return True
+
+            elif response.data is None:
+                log.error(f'list app runs failed', enable_traceback=True)
+                return False
+
+            else:
+                log.info(f'no app runs. {response}')
+                return True
+
+        return False
+
+    @_isConnected
+    def list_app_run_by_playbook_run(
+            self,
+            playbook_run: int,
+            page: int = None,
+            page_size: int = None, **kwargs) -> bool:
+        """list app run by playbook run"""
+
+        app_runs = []
+
+        for app_run in self.list_app_run_generator(page=page, page_size=page_size, **kwargs):
+            if app_run.playbook_run == playbook_run:
+                app_runs.append(app_run)
+
+        return app_runs
+
     @_isConnected
     def list_artifacts(
             self,
@@ -467,7 +531,8 @@ class SplunkSoarClient:
     def list_artifact_generator(
             self,
             page: int = 0,
-            page_size: int = None, **kwargs) -> [Container]:
+            page_size: int = None,
+            max_pages: int = None, **kwargs) -> [Container]:
         """Generator for paging through artifacts"""
 
         page = page
@@ -479,7 +544,7 @@ class SplunkSoarClient:
                 num_pages = response.num_pages
                 log.info(f'{page}/{num_pages} ({round(page / num_pages * 100, 2)}%)')
 
-                if page > num_pages:
+                if page >= num_pages or page >= max_pages:
                     log.info(f'list container finished')
                     return True
 
